/********************************************************************************
 Author : CAC (China Applications Support Team) 

 Date :   Mar, 2014

 File name :  ADIS16228.c 

 Description :	 ADIS16228 SPI communication

 Hardware plateform : 	EVAL-ADuCM360MKZ and ADIS16228/PCBZ
********************************************************************************/

#include <ADuCM360.h>

#include "UrtLib.h"
#include "ClkLib.h"
#include "WdtLib.h"
#include "IntLib.h"
#include "DioLib.h"
#include "SpiLib.h"

#include "ADIS16228.h"
#include "ADuCM360Driver.h"

/*******************************************************************
  @brief void  ADIS16228WriteCommand(unsigned char Address, unsigned int SendValue)
         Write a value to ADIS16228 register
  @param
         unsigned char Address : the write register address 
         unsigned int SendValue: the value to be written
  @return   
         none
*******************************************************************/
void  ADIS16228WriteCommand(unsigned char Address, unsigned int SendValue)
{
    unsigned char SendTemp[2];
    unsigned char ReceiveTemp[2];
  
    SendTemp[0] = Address|0x80;
    SendTemp[1] = SendValue;
    
    SpiFunction(SendTemp, ReceiveTemp, 2);
    Delay1(5);
}

/*******************************************************************
  @brief int ADIS16228ReadCommand(unsigned char Address)
         Read a register value from ADIS16228
  @param
         unsigned char Address: read register address
  @return   
         int ReceiveValue:      read register value
*******************************************************************/
int ADIS16228ReadCommand(unsigned char Address)
{
    int ReceiveValue;
    unsigned char SendTemp[2];
    unsigned char ReceiveTemp[2];

    SendTemp[0] = Address;
    SendTemp[1] = 0;    
    SpiFunction(SendTemp, ReceiveTemp, 2);   
    Delay1(5);
    SpiFunction(SendTemp, ReceiveTemp, 2);
    Delay1(5);
  
    ReceiveValue = ReceiveTemp[0];
    ReceiveValue = (ReceiveValue<<8)+ReceiveTemp[1];
  
    return(ReceiveValue);
}

/*******************************************************************
  @brief void  ADIS16228StartAcquiring(void)
         Command to start acquiring a spectral
  @param
         none
  @return   
         none  
*******************************************************************/
void  ADIS16228StartAcquiring(void)
{
    ADIS16228WriteCommand((GLOB_CMD+1),0x08);    //start command to start acquiring a spectral
}

/*******************************************************************
  @brief void  ADIS16228ReadFFTData(unsigned int DataBuff[], unsigned char ChannelAddress)
         Reading data from the data buffer
  @param
         unsigned int DataBuff[]      : read data buffer 
         unsigned char ChannelAddress : the address of reading axis
  @return   
         none  
*******************************************************************/
void  ADIS16228ReadFFTData(unsigned int DataBuff[], unsigned char AxisAddress)
{
    unsigned int  ReadIndex;
    unsigned char SendTemp[2];
    unsigned char ReceiveTemp[2];

    ADIS16228WriteCommand(BUF_PNTR, 0);                     
    ADIS16228WriteCommand((BUF_PNTR+1), 0);                 //set the buffer index pointer to 0x0000
    SendTemp[0] = AxisAddress;
    SendTemp[1] = 0;    
    SpiFunction(SendTemp, ReceiveTemp, 2);
    Delay1(5);                                              //wait for tSTALL
    for (ReadIndex=0; ReadIndex<256; ReadIndex++)
    {
        SpiFunction(SendTemp, ReceiveTemp, 2);              //The index pointer increments with every x_BUF read command
                                                            //the next set of capture data to load into each capture buffer register automatically
        Delay1(5);
        DataBuff[ReadIndex] = ReceiveTemp[0];
        DataBuff[ReadIndex] = (DataBuff[ReadIndex]<<8)+ReceiveTemp[1];
    }     
}

/*******************************************************************
  @brief ADIS16228ReadThreeAxisData(unsigned int XAxisDataBuff[],unsigned int YAxisDataBuff[],unsigned int ZAxisDataBuff[])
         Read three axis spectral record
  @param
         unsigned int XAxisDataBuff[]: buffer to save X-Axis spectral record
         unsigned int YAxisDataBuff[]: buffer to save Y-Axis spectral record
         unsigned int ZAxisDataBuff[]: buffer to save Z-Axis spectral record
  @return   
         none  
*******************************************************************/
void   ADIS16228ReadThreeAxisData(unsigned int XAxisDataBuff[],unsigned int YAxisDataBuff[],unsigned int ZAxisDataBuff[])
{
    unsigned int StatusValue;
    do
    {
        StatusValue = DioRd(pADI_GP2);
    }while((StatusValue&0x01) == 0x01);       //using the DIO1 indicate ready
    
    ADIS16228ReadFFTData(XAxisDataBuff, X_BUF);
    ADIS16228ReadFFTData(YAxisDataBuff, Y_BUF); 
    ADIS16228ReadFFTData(ZAxisDataBuff, Z_BUF);    
}
